Index: trunk/src/tmcsim/simulationmanager/SimulationManager.java
===================================================================
--- trunk/src/tmcsim/simulationmanager/SimulationManager.java	(revision 658)
+++ trunk/src/tmcsim/simulationmanager/SimulationManager.java	(revision 664)
@@ -22,21 +22,10 @@
  * communicator and applying diversions. A history of all events is shown as
  * well.<br>
  * The SimulationManager may be started at any point before, during, or after a
  * simulation has begun. The SimulationManager connects to the CADSimulator and
  * communicates through Java RMI methods. If two SimulationManagers are started,
  * the second one started, chronologically, will receive communication from the
- * CADSimulator. <br><br>
- * The properties file for the SimulationManager class contains the following
- * data.<br>
- * <code>
- * -----------------------------------------------------------------------------<br>
- * Host Name The host name where the CADSimulator is located.<br>
- * Error File The target file to use for error logging.<br>
- * -----------------------------------------------------------------------------<br>
- * Example File: <br>
- * CADSimulatorHost = localhost <br>
- * ErrorFile = sim_mgr_error.xml <br>
- * -----------------------------------------------------------------------------<br>
- * </code>
+ * CADServer. (It's a bad idea to do this, there's no normal use case
+ * that requires it.)<br><br>
  *
  * @author Matthew Cechini (mcechini@calpoly.edu)
@@ -46,5 +35,5 @@
 {
 
-    private static final String CONFIG_FILE_NAME = "sim_manager_config.properties";
+    private static final String CONFIG_FILE_NAME = "sim_manager.properties";
     /*
      * Default name of folder that contains Scenario xml files.
@@ -65,6 +54,6 @@
     {
 
-        CAD_SIM_HOST("CADSimulatorHost"),
-        CAD_SIM_PORT("CADSimulatorRMIPort"),
+        CAD_SERVER_HOST("CADServerHost"),
+        CAD_SERVER_PORT("CADServerRMIPort"),
         SCENARIOS_DIR("ScenariosDir"),
         FAKE_PARAMICS("FakeParamicsConnection");
@@ -116,10 +105,10 @@
 
             //make sure properties aren't null
-            if (simManagerProperties.getProperty(PROPERTIES.CAD_SIM_HOST.name) == null)
+            if (simManagerProperties.getProperty(PROPERTIES.CAD_SERVER_HOST.name) == null)
             {
                 throw new Exception("CAD Simulator host property is null.");
             }
 
-            if (simManagerProperties.getProperty(PROPERTIES.CAD_SIM_PORT.name) == null)
+            if (simManagerProperties.getProperty(PROPERTIES.CAD_SERVER_PORT.name) == null)
             {
                 throw new Exception("CAD Simulator port property is null.");
@@ -138,6 +127,6 @@
         {
             theSimManagerModel = new SimulationManagerModel(
-                    simManagerProperties.getProperty(PROPERTIES.CAD_SIM_HOST.name).trim(),
-                    simManagerProperties.getProperty(PROPERTIES.CAD_SIM_PORT.name).trim());
+                    simManagerProperties.getProperty(PROPERTIES.CAD_SERVER_HOST.name).trim(),
+                    simManagerProperties.getProperty(PROPERTIES.CAD_SERVER_PORT.name).trim());
 
             //Construct the SimulationManagerView and set up the Model-View references.
@@ -22,21 +22,10 @@
  * communicator and applying diversions. A history of all events is shown as
  * well.<br>
- * The SimulationManager may be started at any point before, during, or after a
- * simulation has begun. The SimulationManager connects to the CADSimulator and
+ * The CADServer must be running before the SimulationManager is started. 
+ * SimulationManager connects to the CADServer and
  * communicates through Java RMI methods. If two SimulationManagers are started,
  * the second one started, chronologically, will receive communication from the
